Package: pdftools
Type: Package
Title: Text Extraction, Rendering and Converting of PDF Documents
Version: 3.9.0
Authors@R: person("Jeroen", "Ooms", role = c("aut", "cre"), email = "jeroenooms@gmail.com",
      comment = c(ORCID = "0000-0002-4035-0289"))
Description: Utilities based on 'libpoppler' <https://poppler.freedesktop.org> for extracting
    text, fonts, attachments and metadata from a PDF file. Also supports high quality rendering
    of PDF documents into PNG, JPEG, TIFF format, or into raw bitmap vectors for further 
    processing in R.
License: MIT + file LICENSE
URL: https://ropensci.r-universe.dev/pdftools,
        https://docs.ropensci.org/pdftools/
BugReports: https://github.com/ropensci/pdftools/issues
SystemRequirements: Poppler C++ API: libpoppler-cpp-dev (deb) or
        poppler-cpp-devel (rpm), and poppler-data (rpm/deb) package.
Encoding: UTF-8
Imports: Rcpp (>= 0.12.12), qpdf
LinkingTo: Rcpp
Suggests: png, webp, tesseract, testthat
RoxygenNote: 7.3.2
NeedsCompilation: yes
Packaged: 2026-05-14 12:38:00 UTC; jeroen
Author: Jeroen Ooms [aut, cre] (ORCID: <https://orcid.org/0000-0002-4035-0289>)
Maintainer: Jeroen Ooms <jeroenooms@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-14 13:30:03 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-05-14 14:35:55 UTC; unix
Archs: pdftools.so.dSYM
