# Generated by roxygen2: do not edit by hand

export(pdf_attachments)
export(pdf_combine)
export(pdf_compress)
export(pdf_convert)
export(pdf_data)
export(pdf_fonts)
export(pdf_info)
export(pdf_length)
export(pdf_ocr_data)
export(pdf_ocr_text)
export(pdf_pagesize)
export(pdf_render_page)
export(pdf_split)
export(pdf_subset)
export(pdf_text)
export(pdf_toc)
export(poppler_config)
importFrom(Rcpp,sourceCpp)
importFrom(qpdf,pdf_combine)
importFrom(qpdf,pdf_compress)
importFrom(qpdf,pdf_length)
importFrom(qpdf,pdf_split)
importFrom(qpdf,pdf_subset)
useDynLib(pdftools)
