# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

set_poppler_data <- function(path) {
    .Call('_pdftools_set_poppler_data', PACKAGE = 'pdftools', path)
}

get_poppler_config <- function() {
    .Call('_pdftools_get_poppler_config', PACKAGE = 'pdftools')
}

poppler_pdf_info <- function(x, opw, upw) {
    .Call('_pdftools_poppler_pdf_info', PACKAGE = 'pdftools', x, opw, upw)
}

poppler_pdf_data <- function(x, opw, upw) {
    .Call('_pdftools_poppler_pdf_data', PACKAGE = 'pdftools', x, opw, upw)
}

poppler_pdf_text <- function(x, opw, upw) {
    .Call('_pdftools_poppler_pdf_text', PACKAGE = 'pdftools', x, opw, upw)
}

poppler_pdf_pagesize <- function(x, opw, upw) {
    .Call('_pdftools_poppler_pdf_pagesize', PACKAGE = 'pdftools', x, opw, upw)
}

poppler_pdf_fonts <- function(x, opw, upw) {
    .Call('_pdftools_poppler_pdf_fonts', PACKAGE = 'pdftools', x, opw, upw)
}

poppler_pdf_files <- function(x, opw, upw) {
    .Call('_pdftools_poppler_pdf_files', PACKAGE = 'pdftools', x, opw, upw)
}

poppler_pdf_toc <- function(x, opw, upw) {
    .Call('_pdftools_poppler_pdf_toc', PACKAGE = 'pdftools', x, opw, upw)
}

poppler_render_page <- function(x, pagenum, dpi, opw, upw, antialiasing = TRUE, text_antialiasing = TRUE) {
    .Call('_pdftools_poppler_render_page', PACKAGE = 'pdftools', x, pagenum, dpi, opw, upw, antialiasing, text_antialiasing)
}

poppler_convert <- function(x, format, pages, names, dpi, opw, upw, antialiasing = TRUE, text_antialiasing = TRUE, verbose = TRUE) {
    .Call('_pdftools_poppler_convert', PACKAGE = 'pdftools', x, format, pages, names, dpi, opw, upw, antialiasing, text_antialiasing, verbose)
}

set_error_callback <- function() {
    invisible(.Call('_pdftools_set_error_callback', PACKAGE = 'pdftools'))
}

